Reference
=========

.. contents:: :local:

-------------


Schema
------

.. autoclass:: zlmdb.Schema
    :members:


Database
--------

.. autoclass:: zlmdb.Database
    :members:


Transaction
-----------

* :class:`zlmdb.Transaction`
* :class:`zlmdb.TransactionStats`

-------

.. autoclass:: zlmdb.Transaction
    :members:

.. autoclass:: zlmdb.TransactionStats
    :members:


PersistentMap
-------------

* :class:`zlmdb._pmap.PersistentMap`
* :class:`zlmdb._pmap.PersistentMapIterator`

-------

.. autoclass:: zlmdb._pmap.PersistentMap
    :members:

.. autoclass:: zlmdb._pmap.PersistentMapIterator
    :members:


Typed PersistentMap
-------------------

* :class:`zlmdb.MapBytes16FlatBuffers`
* :class:`zlmdb.MapBytes16TimestampUuid`
* :class:`zlmdb.MapBytes16TimestampUuidFlatBuffers`
* :class:`zlmdb.MapBytes20Bytes16`
* :class:`zlmdb.MapBytes20Bytes20`
* :class:`zlmdb.MapBytes20Bytes20FlatBuffers`
* :class:`zlmdb.MapBytes20Bytes20Timestamp`
* :class:`zlmdb.MapBytes20FlatBuffers`
* :class:`zlmdb.MapBytes20StringFlatBuffers`
* :class:`zlmdb.MapBytes20TimestampBytes20`
* :class:`zlmdb.MapBytes20TimestampUuid`
* :class:`zlmdb.MapBytes20Uuid`
* :class:`zlmdb.MapBytes32Bytes32`
* :class:`zlmdb.MapBytes32Bytes32FlatBuffers`
* :class:`zlmdb.MapBytes32FlatBuffers`
* :class:`zlmdb.MapBytes32StringFlatBuffers`
* :class:`zlmdb.MapBytes32Timestamp`
* :class:`zlmdb.MapBytes32Uuid`
* :class:`zlmdb.MapBytes32UuidFlatBuffers`
* :class:`zlmdb.MapOid3FlatBuffers`
* :class:`zlmdb.MapOidCbor`
* :class:`zlmdb.MapOidFlatBuffers`
* :class:`zlmdb.MapOidJson`
* :class:`zlmdb.MapOidOid`
* :class:`zlmdb.MapOidOidFlatBuffers`
* :class:`zlmdb.MapOidOidOid`
* :class:`zlmdb.MapOidOidSet`
* :class:`zlmdb.MapOidPickle`
* :class:`zlmdb.MapOidString`
* :class:`zlmdb.MapOidStringOid`
* :class:`zlmdb.MapOidTimestampFlatBuffers`
* :class:`zlmdb.MapOidTimestampOid`
* :class:`zlmdb.MapOidTimestampStringOid`
* :class:`zlmdb.MapOidUuid`
* :class:`zlmdb.MapSlotUuidUuid`
* :class:`zlmdb.MapStringCbor`
* :class:`zlmdb.MapStringFlatBuffers`
* :class:`zlmdb.MapStringJson`
* :class:`zlmdb.MapStringOid`
* :class:`zlmdb.MapStringOidOid`
* :class:`zlmdb.MapStringPickle`
* :class:`zlmdb.MapStringString`
* :class:`zlmdb.MapStringStringStringUuid`
* :class:`zlmdb.MapStringStringUuid`
* :class:`zlmdb.MapStringTimestampCbor`
* :class:`zlmdb.MapStringUuid`
* :class:`zlmdb.MapTimestampBytes32FlatBuffers`
* :class:`zlmdb.MapTimestampFlatBuffers`
* :class:`zlmdb.MapTimestampStringCbor`
* :class:`zlmdb.MapTimestampStringFlatBuffers`
* :class:`zlmdb.MapTimestampUuidCbor`
* :class:`zlmdb.MapTimestampUuidFlatBuffers`
* :class:`zlmdb.MapTimestampUuidStringFlatBuffers`
* :class:`zlmdb.MapUint16UuidTimestampFlatBuffers`
* :class:`zlmdb.MapUuidBytes20Bytes20Uint8UuidFlatBuffers`
* :class:`zlmdb.MapUuidBytes20Uint8FlatBuffers`
* :class:`zlmdb.MapUuidBytes20Uint8UuidFlatBuffers`
* :class:`zlmdb.MapUuidBytes32FlatBuffers`
* :class:`zlmdb.MapUuidCbor`
* :class:`zlmdb.MapUuidFlatBuffers`
* :class:`zlmdb.MapUuidJson`
* :class:`zlmdb.MapUuidOid`
* :class:`zlmdb.MapUuidPickle`
* :class:`zlmdb.MapUuidString`
* :class:`zlmdb.MapUuidStringFlatBuffers`
* :class:`zlmdb.MapUuidStringOid`
* :class:`zlmdb.MapUuidStringUuid`
* :class:`zlmdb.MapUuidTimestampBytes32`
* :class:`zlmdb.MapUuidTimestampCbor`
* :class:`zlmdb.MapUuidTimestampFlatBuffers`
* :class:`zlmdb.MapUuidTimestampUuid`
* :class:`zlmdb.MapUuidTimestampUuidFlatBuffers`
* :class:`zlmdb.MapUuidUuid`
* :class:`zlmdb.MapUuidUuidCbor`
* :class:`zlmdb.MapUuidUuidFlatBuffers`
* :class:`zlmdb.MapUuidUuidSet`
* :class:`zlmdb.MapUuidUuidStringFlatBuffers`
* :class:`zlmdb.MapUuidUuidStringUuid`
* :class:`zlmdb.MapUuidUuidUuid`
* :class:`zlmdb.MapUuidUuidUuidStringUuid`
* :class:`zlmdb.MapUuidUuidUuidUuid`
* :class:`zlmdb.MapUuidUuidUuidUuidUuid`

------

.. autoclass:: zlmdb.MapBytes16FlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes16TimestampUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes16TimestampUuidFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes20Bytes16
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes20Bytes20
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes20Bytes20FlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes20Bytes20Timestamp
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes20FlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes20StringFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes20TimestampBytes20
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes20TimestampUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes20Uuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes32Bytes32
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes32Bytes32FlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes32FlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes32StringFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes32Timestamp
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes32Uuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapBytes32UuidFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOid3FlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidCbor
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidJson
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidOid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidOidFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidOidOid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidOidSet
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidPickle
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidString
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidStringOid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidTimestampFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidTimestampOid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidTimestampStringOid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapOidUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapSlotUuidUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapStringCbor
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapStringFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapStringJson
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapStringOid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapStringOidOid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapStringPickle
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapStringString
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapStringStringStringUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapStringStringUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapStringTimestampCbor
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapStringUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapTimestampBytes32FlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapTimestampFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapTimestampStringCbor
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapTimestampStringFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapTimestampUuidCbor
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapTimestampUuidFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapTimestampUuidStringFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUint16UuidTimestampFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidBytes20Bytes20Uint8UuidFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidBytes20Uint8FlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidBytes20Uint8UuidFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidBytes32FlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidCbor
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidJson
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidOid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidPickle
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidString
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidStringFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidStringOid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidStringUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidTimestampBytes32
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidTimestampCbor
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidTimestampFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidTimestampUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidTimestampUuidFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidUuidCbor
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidUuidFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidUuidSet
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidUuidStringFlatBuffers
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidUuidStringUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidUuidUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidUuidUuidStringUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidUuidUuidUuid
    :members:
    :show-inheritance:

.. autoclass:: zlmdb.MapUuidUuidUuidUuidUuid
    :members:
    :show-inheritance:


Key Types
---------

* :class:`zlmdb._types._Bytes16KeysMixin`
* :class:`zlmdb._types._Bytes16TimestampKeysMixin`
* :class:`zlmdb._types._Bytes16TimestampUuidKeysMixin`
* :class:`zlmdb._types._Bytes20Bytes20KeysMixin`
* :class:`zlmdb._types._Bytes20KeysMixin`
* :class:`zlmdb._types._Bytes20StringKeysMixin`
* :class:`zlmdb._types._Bytes20TimestampKeysMixin`
* :class:`zlmdb._types._Bytes32Bytes32KeysMixin`
* :class:`zlmdb._types._Bytes32KeysMixin`
* :class:`zlmdb._types._Bytes32StringKeysMixin`
* :class:`zlmdb._types._Bytes32UuidKeysMixin`
* :class:`zlmdb._types._Oid3KeysMixin`
* :class:`zlmdb._types._OidKeysMixin`
* :class:`zlmdb._types._OidOidKeysMixin`
* :class:`zlmdb._types._OidStringKeysMixin`
* :class:`zlmdb._types._OidTimestampKeysMixin`
* :class:`zlmdb._types._OidTimestampStringKeysMixin`
* :class:`zlmdb._types._SlotUuidKeysMixin`
* :class:`zlmdb._types._StringKeysMixin`
* :class:`zlmdb._types._StringOidKeysMixin`
* :class:`zlmdb._types._StringStringKeysMixin`
* :class:`zlmdb._types._StringStringStringKeysMixin`
* :class:`zlmdb._types._StringTimestampKeysMixin`
* :class:`zlmdb._types._TimestampBytes32KeysMixin`
* :class:`zlmdb._types._TimestampKeysMixin`
* :class:`zlmdb._types._TimestampStringKeysMixin`
* :class:`zlmdb._types._TimestampUuidKeysMixin`
* :class:`zlmdb._types._TimestampUuidStringKeysMixin`
* :class:`zlmdb._types._Uint16UuidTimestampKeysMixin`
* :class:`zlmdb._types._UuidBytes20Bytes20Uint8UuidKeysMixin`
* :class:`zlmdb._types._UuidBytes20Uint8KeysMixin`
* :class:`zlmdb._types._UuidBytes20Uint8UuidKeysMixin`
* :class:`zlmdb._types._UuidBytes32KeysMixin`
* :class:`zlmdb._types._UuidKeysMixin`
* :class:`zlmdb._types._UuidStringKeysMixin`
* :class:`zlmdb._types._UuidTimestampKeysMixin`
* :class:`zlmdb._types._UuidTimestampUuidKeysMixin`
* :class:`zlmdb._types._UuidUuidKeysMixin`
* :class:`zlmdb._types._UuidUuidStringKeysMixin`
* :class:`zlmdb._types._UuidUuidUuidKeysMixin`
* :class:`zlmdb._types._UuidUuidUuidStringKeysMixin`
* :class:`zlmdb._types._UuidUuidUuidUuidKeysMixin`

------

.. autoclass:: zlmdb._types._Bytes16KeysMixin
        :members:

.. autoclass:: zlmdb._types._Bytes16TimestampKeysMixin
        :members:

.. autoclass:: zlmdb._types._Bytes16TimestampUuidKeysMixin
        :members:

.. autoclass:: zlmdb._types._Bytes20Bytes20KeysMixin
        :members:

.. autoclass:: zlmdb._types._Bytes20KeysMixin
        :members:

.. autoclass:: zlmdb._types._Bytes20StringKeysMixin
        :members:

.. autoclass:: zlmdb._types._Bytes20TimestampKeysMixin
        :members:

.. autoclass:: zlmdb._types._Bytes32Bytes32KeysMixin
        :members:

.. autoclass:: zlmdb._types._Bytes32KeysMixin
        :members:

.. autoclass:: zlmdb._types._Bytes32StringKeysMixin
        :members:

.. autoclass:: zlmdb._types._Bytes32UuidKeysMixin
        :members:

.. autoclass:: zlmdb._types._Oid3KeysMixin
        :members:

.. autoclass:: zlmdb._types._OidKeysMixin
        :members:

.. autoclass:: zlmdb._types._OidOidKeysMixin
        :members:

.. autoclass:: zlmdb._types._OidStringKeysMixin
        :members:

.. autoclass:: zlmdb._types._OidTimestampKeysMixin
        :members:

.. autoclass:: zlmdb._types._OidTimestampStringKeysMixin
        :members:

.. autoclass:: zlmdb._types._SlotUuidKeysMixin
        :members:

.. autoclass:: zlmdb._types._StringKeysMixin
        :members:

.. autoclass:: zlmdb._types._StringOidKeysMixin
        :members:

.. autoclass:: zlmdb._types._StringStringKeysMixin
        :members:

.. autoclass:: zlmdb._types._StringStringStringKeysMixin
        :members:

.. autoclass:: zlmdb._types._StringTimestampKeysMixin
        :members:

.. autoclass:: zlmdb._types._TimestampBytes32KeysMixin
        :members:

.. autoclass:: zlmdb._types._TimestampKeysMixin
        :members:

.. autoclass:: zlmdb._types._TimestampStringKeysMixin
        :members:

.. autoclass:: zlmdb._types._TimestampUuidKeysMixin
        :members:

.. autoclass:: zlmdb._types._TimestampUuidStringKeysMixin
        :members:

.. autoclass:: zlmdb._types._Uint16UuidTimestampKeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidBytes20Bytes20Uint8UuidKeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidBytes20Uint8KeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidBytes20Uint8UuidKeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidBytes32KeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidKeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidStringKeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidTimestampKeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidTimestampUuidKeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidUuidKeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidUuidStringKeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidUuidUuidKeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidUuidUuidStringKeysMixin
        :members:

.. autoclass:: zlmdb._types._UuidUuidUuidUuidKeysMixin
        :members:


Value Types
-----------

* :class:`zlmdb._types._Bytes16ValuesMixin`
* :class:`zlmdb._types._Bytes20TimestampValuesMixin`
* :class:`zlmdb._types._Bytes20ValuesMixin`
* :class:`zlmdb._types._Bytes32ValuesMixin`
* :class:`zlmdb._types._CborValuesMixin`
* :class:`zlmdb._types._FlatBuffersValuesMixin`
* :class:`zlmdb._types._JsonValuesMixin`
* :class:`zlmdb._types._OidSetValuesMixin`
* :class:`zlmdb._types._OidValuesMixin`
* :class:`zlmdb._types._Pickle5ValuesMixin`
* :class:`zlmdb._types._PickleValuesMixin`
* :class:`zlmdb._types._StringSetValuesMixin`
* :class:`zlmdb._types._StringValuesMixin`
* :class:`zlmdb._types._TimestampValuesMixin`
* :class:`zlmdb._types._UuidSetValuesMixin`
* :class:`zlmdb._types._UuidValuesMixin`

------

.. autoclass:: zlmdb._types._Bytes16ValuesMixin
        :members:

.. autoclass:: zlmdb._types._Bytes20TimestampValuesMixin
        :members:

.. autoclass:: zlmdb._types._Bytes20ValuesMixin
        :members:

.. autoclass:: zlmdb._types._Bytes32ValuesMixin
        :members:

.. autoclass:: zlmdb._types._CborValuesMixin
        :members:

.. autoclass:: zlmdb._types._FlatBuffersValuesMixin
        :members:

.. autoclass:: zlmdb._types._JsonValuesMixin
        :members:

.. autoclass:: zlmdb._types._OidSetValuesMixin
        :members:

.. autoclass:: zlmdb._types._OidValuesMixin
        :members:

.. autoclass:: zlmdb._types._Pickle5ValuesMixin
        :members:

.. autoclass:: zlmdb._types._PickleValuesMixin
        :members:

.. autoclass:: zlmdb._types._StringSetValuesMixin
        :members:

.. autoclass:: zlmdb._types._StringValuesMixin
        :members:

.. autoclass:: zlmdb._types._TimestampValuesMixin
        :members:

.. autoclass:: zlmdb._types._UuidSetValuesMixin
        :members:

.. autoclass:: zlmdb._types._UuidValuesMixin
        :members:
